      module tolerance	
         real, parameter :: epsilon = 1.0E-4
      end module tolerance	
      module model	
         integer, parameter :: nfl = 6
         real, dimension(nfl) :: prob
         real, dimension(nfl+1) :: cum
      end module model
      subroutine lifttime(t)	! compute the lift travel time
      use model
      real, dimension(nfl) :: tm
*
*     Loop over initial and final floors
*
      do in = 1,nfl
         sum = 0.
         do j = 1,nfl
            sum = sum + prob(j)*abs(j-in)
         end do
         do ix = 1,nfl
            if (in == ix) then
               tm(ix) = 0.
            else if (in < ix) then
               tm(ix) = ix-in + sum + t*(0.5+
     1          cum(ix-1)-cum(in)-cum(in)*(1-cum(in-1)))
            else
               tm(ix) = in-ix + sum + t*(0.5+
     1          cum(in)-cum(ix+1)-cum(in)*(1-cum(in-1)))
            end if
         end do
         write(*,'(i4,6f7.1)') in, (15*abs(in-j)-tm(j),j=1,nfl)
      end do
*
      return
      end subroutine lifttime
      subroutine prepare       		! prepare the cumulative probs
      use model
      use tolerance
*
*     The definition is not exactly that in the notes
*
      cum(1) = 0.
      do j = 2,nfl+1
         cum(j) = cum(j-1) + prob(j-1)
      end do
*
*     Check that the input was correct
*
      if (abs(cum(nfl+1)-1.0) > epsilon) then
         stop 'Input probabilities do not add to unity'
      end if
*
      return
      end subroutine prepare
      program main
      use model
*
*     Outer loop over K, inner loop over t
*
      do k = 1,20
*
*        Set up the model
*
         prob = 1.0/(nfl-1+k)		! array assignment
         prob(3) = k*prob(3)		! array element assignment
         call prepare
*
*        Loop over the remaining model parameter
*
         do j = 2,50
            t=j*0.5
            write(*,6001) k, t
            call lifttime(t)
         end do
      end do
*
 6001 format(//,'K=',i2,5x,'t=',f4.1)
      end
